package io.better.toutiao.api.advertisingput;

import lombok.AllArgsConstructor;
import lombok.Getter;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

/**
 * The interface Advertising group api.
 *
 * @author better create in 2019-04-28 16:27
 */
@FeignClient(value = "", url = "")
public interface AdvertisingGroupApi {

    /**
     * The constant BUDGET_MODE_INFINITE.
     */
    String BUDGET_MODE_INFINITE = "BUDGET_MODE_INFINITE";

    /**
     * The constant BUDGET_MODE_DAY.
     */
    String BUDGET_MODE_DAY = "BUDGET_MODE_DAY";

    /**
     * 广告投放-获取某广告主的广告组信息
     *
     * @param accessToken  访问凭证
     * @param advertiserId 广告主ID
     * @param page         当前页
     * @param pageSize     每页记录数
     * @param filtering    过滤字段
     * @param fields       查询字段
     * @return advertising group
     */
    @GetMapping(value = "https://ad.toutiao.com/open_api/2/campaign/get/")
    List<Object> getAdvertisingGroup(@RequestHeader("Access-Token") String accessToken,
                                     @RequestParam("advertiser_id") Long advertiserId,
                                     @RequestParam(value = "page", defaultValue = "1", required = false) Integer page,
                                     @RequestParam(value = "page_size", defaultValue = "20", required = false) Integer pageSize,
                                     @RequestParam(value = "filtering", required = false) Map<String, Object> filtering,
                                     @RequestParam(value = "fields", required = false) String[] fields);

    /**
     * 广告投放-为某广告主创建广告组信息
     *
     * @param accessToken  访问凭证
     * @param advertiserId 广告主ID
     * @param campaignName 广告组名称
     * @param budgetMode   广告组预算类型
     * @param budget       广告组预算
     * @param landingType  广告组推广目的
     * @param uniqueFk     第三方唯一键，保证幂等性
     * @return the list
     */
    @PostMapping(value = "https://ad.toutiao.com/open_api/2/campaign/create/")
    List<Object> createAdvertisingGroup(@RequestHeader("Access-Token") String accessToken,
                                        @RequestParam("advertiser_id") String advertiserId,
                                        @RequestParam("campaign_name") String campaignName,
                                        @RequestParam("budget_mode") String budgetMode,
                                        @RequestParam(value = "budget", required = false) Long budget,
                                        @RequestParam(value = "landing_type") String landingType,
                                        @RequestParam(value = "unique_fk", required = false) String uniqueFk);

    /**
     * 广告投放-修改某广告主的广告组信息
     *
     * @param accessToken  访问凭证
     * @param advertiserId 广告主ID
     * @param campaignId   广告组ID
     * @param campaignName 广告组名称
     * @param modifyTime   修改时间
     * @param budgetMode   广告组预算类型
     * @param budget       广告组预算
     * @return the list
     */
    @PostMapping(value = "https://ad.toutiao.com/open_api/2/campaign/update/")
    List<Object> updateAdvertisingGroup(@RequestHeader("Access-Token") String accessToken,
                                        @RequestParam("advertiser_id") String advertiserId,
                                        @RequestParam("campaign_id") Long campaignId,
                                        @RequestParam(value = "campaign_name", required = false) String campaignName,
                                        @RequestParam("modify_time") String modifyTime,
                                        @RequestParam(value = "budget_mode", required = false) String budgetMode,
                                        @RequestParam(value = "budget", required = false) Long budget);

    /**
     * 广告投放-修改某广告主的广告组状态信息
     *
     * @param accessToken  访问凭证
     * @param advertiserId 广告主ID
     * @param campaignIds  广告组ID集合
     * @param optStatus    更新状态
     * @return
     */
    List<Object> updateAdvertisingGroupStatus(@RequestHeader("Access-Token") String accessToken,
                                              @RequestParam("advertiser_id") String advertiserId,
                                              @RequestParam("campaign_ids") Long[] campaignIds,
                                              @RequestParam("opt_status") String optStatus);

    /**
     * 广告组推广目的枚举
     */
    @Getter
    @AllArgsConstructor
    enum LandingType {

        /**
         * 销售线索收集
         */
        LINK("LINK"),
        /**
         * 推广应用下载
         */
        APP("APP"),
        /**
         * 产品目录
         */
        DPA("DPA"),
        /**
         * 商品推广（鲁班）
         */
        GOODS("GOODS");

        private String landingType;
    }
}
